@@ -46,7 +46,7 @@ class Archiver extends CMSModule
 
 	function GetVersion()
 	{
-		return '0.2.1';
+		return '0.2.3';
 	}
 
 	function GetHelp()
@@ -405,20 +405,21 @@ class Archiver extends CMSModule
 			$contentops = $gCms->GetContentOperations();
 			$contentops->LoadContentType($row['item_subtype']);
 		}
+		else if ($row['item_type'] == $this->TYPE_STYLESHEET)
+		{
+			$cssOps = $gCms->GetStylesheetOperations();
+		}
+		else if ($row['item_type'] == $this->TYPE_TEMPLATE)
+		{
+			$cssOps = $gCms->GetTemplateOperations();
+		}
 		$restore = UnserializeObject($row['serialized_item']);
 		return $restore;
 	}
 
 	function RestoreObject($id, &$params, $returnid, $message='')
 	{
-		/*    	global $gCms;
-		$db = &$this->cms->db;
-
-		$query = 'SELECT serialized_item FROM '.cms_db_prefix().
-		'module_archiver_item WHERE archive_id=?';
-		$serobj = $db->GetOne($query, array($params['archive_id']));
-		$restore = UnserializeObject($serobj);
-		*/
+		global $gCms;
 		$restore = $this->retrieveSerializedObject($params['archive_id']);
 		// get the current object, and update select attributes. That way, we don't screw up hierarchy, etc.
 		if ($params['type_id'] == $this->TYPE_CONTENT)
@@ -437,8 +438,13 @@ class Archiver extends CMSModule
 		}	
 		elseif ($params['type_id'] == $this->TYPE_STYLESHEET)
 		{
-			// FIXME
-			$current = '';
+			$cssOps = &$gCms->GetStylesheetOperations();
+			$current = $cssOps->LoadStylesheetByID($params['item_id'], true);
+			$current->name = $restore->name;
+			$current->value = $restore->value;
+			$current->media_type = $restore->media_type;
+			$current->Save();
+			$msg = $this->Lang('restored_stylesheet', array($current->name, $params['revision_number']));
 		}
 		elseif ($params['type_id'] == $this->TYPE_HTMLBLOB)
 		{
@@ -450,7 +456,8 @@ class Archiver extends CMSModule
 		}
 		elseif ($params['type_id'] == $this->TYPE_TEMPLATE)
 		{
-			$current = TemplateOperations::LoadTemplateByID($params['item_id']);
+			$templateOps = &$gCms->GetTemplateOperations();
+			$current = $templateOps->LoadTemplateByID($params['item_id']);
 			$current->content = $restore->content;
 			$current->name = $restore->name;
 			$current->stylesheet = $restore->stylesheet;
@@ -772,36 +779,13 @@ class Archiver extends CMSModule
 		$this->smarty->assign_by_ref('message', $message);
 		if ($params['preview'] && $params['type_id'] == $this->TYPE_CONTENT)
 		{
-			$contentobj = $this->retrieveSerializedObject($params['archive_id']);
-			$data = array();
-			$data["content_id"] = $contentobj->Id();
-			$data["title"] = $contentobj->Name();
-			$data["menutext"] = $contentobj->MenuText();
-			$data["content"] = $contentobj->Show();
-			$data["template_id"] = $contentobj->TemplateId();
-			$data["hierarchy"] = $contentobj->Hierarchy();
+			$restore = $this->retrieveSerializedObject($params['archive_id']);
 
-			$templateobj = TemplateOperations::LoadTemplateById($contentobj->TemplateId());
-			$data['template'] = $templateobj->content;
-
-			$stylesheetobj = get_stylesheet($contentobj->TemplateId());
-			$data['encoding'] = $stylesheetobj['encoding'];
-			$data['stylesheet'] = $stylesheetobj['stylesheet'];
-
-			$tmpfname = '';
-			if (is_writable($config["previews_path"]))
-			{
-				$tmpfname = tempnam($config["previews_path"], "cmspreview");
-			}
-			else
-			{
-				$tmpfname = tempnam(TMP_CACHE_LOCATION, "cmspreview");
-			}
-			$handle = fopen($tmpfname, "w");
-			fwrite($handle, serialize($data));
-			fclose($handle);
+			$tmpfname = $this->createtmpfname($restore);
+			$_SESSION['cms_preview'] = str_replace('\\','/',$tmpfname);			
 			$this->smarty->assign('preview_file',
-			$config["root_url"] .'/preview.php?tmpfile='.urlencode(basename($tmpfname)));
+			$config["root_url"] .'/index.php?'.$gCms->config['query_var'].'=__CMS_PREVIEW_PAGE__');
+
 			$this->smarty->assign('title_preview', $this->Lang('title_preview',$params['revision_number']));
 
 		}
@@ -811,6 +795,44 @@ class Archiver extends CMSModule
 
 	}
 
+	function createtmpfname(&$contentobj)
+	{
+		global $gCms;
+		$config =& $gCms->GetConfig();
+		$templateops =& $gCms->GetTemplateOperations();
+
+		$data["content_id"] = $contentobj->Id();
+		$data['content_type'] = $contentobj->Type();
+		$data["title"] = $contentobj->Name();
+		$data["menutext"] = $contentobj->MenuText();
+		$data["content"] = $contentobj->Show();
+		$data["template_id"] = $contentobj->TemplateId();
+		$data["hierarchy"] = $contentobj->Hierarchy();
+
+		$templateobj = $templateops->LoadTemplateById($contentobj->TemplateId());
+		$data['template'] = $templateobj->content;
+
+		$stylesheetobj = get_stylesheet($contentobj->TemplateId());
+		$data['encoding'] = $stylesheetobj['encoding'];
+		$data['serialized_content'] = serialize($contentobj);
+
+		$tmpfname = '';
+		if (is_writable($config["previews_path"]))
+		{
+			$tmpfname = tempnam($config["previews_path"], "cmspreview");
+		}
+		else
+		{
+			$tmpfname = tempnam(TMP_CACHE_LOCATION, "cmspreview");
+		}
+		$handle = fopen($tmpfname, "w");
+		fwrite($handle, serialize($data));
+		fclose($handle);
+
+		return $tmpfname;
+	}
+
+
 	function DisplayArchivesSimple($id, &$params, $returnid, $message='')
 	{
 		global $gCms;
